# (c) Copyright 2010. CodeWeavers, Inc.

import os
import traceback
import urllib2

import cxlog

def get_proxy_gnome(protocol):
    # pylint: disable-msg=F0401
    import gconf
    client = gconf.Client()

    if protocol == 'https':
        protocol = 'secure' #gconf calls https "secure"

    if protocol == 'http':
        if not client.get_value('/system/http_proxy/use_http_proxy'):
            return ''

        host = client.get_value('/system/http_proxy/host')
        port = client.get_value('/system/http_proxy/port')
    else:
        host = client.get_value('/system/proxy/%s_host' % protocol)
        port = client.get_value('/system/proxy/%s_port' % protocol)

    if not host or not port:
        return ''

    if client.get_value('/system/http_proxy/use_authentication'):
        # Not sure if we should do this unconditionally, but gconf provides no other authentication info
        auth_user = client.get_value('/system/http_proxy/authentication_user')
        auth_pass = client.get_value('/system/http_proxy/authentication_password')
        auth_info = '%s:%s@' % (auth_user, auth_pass)
    else:
        auth_info = ''

    return '%s%s:%s' % (auth_info, host, port)

def get_proxy(protocol):
    if os.environ.get('DESKTOP_SESSION') == 'gnome' or \
       'GNOME_DESKTOP_SESSION_ID' in os.environ:
        try:
            return get_proxy_gnome(protocol)
        except:
            cxlog.warn("Couldn't get proxy info for GNOME:\n%s" % traceback.format_exc())

    if protocol+'_proxy' in os.environ:
        return os.environ[protocol+'_proxy']

    return ''

def getproxies():
    proxies = {}

    for protocol in ('http', 'https', 'ftp', 'socks'):
        url = get_proxy(protocol)
        if url != '':
            proxies[protocol] = url

    return proxies

def setup_proxy():
    proxies = getproxies()

    if proxies:
        proxy_handler = urllib2.ProxyHandler(proxies)

        opener = urllib2.build_opener(proxy_handler)

        urllib2.install_opener(opener)

if __name__ == '__main__':
    print getproxies()

